Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func String ¶
String interprets a brace expansion expression and returns the list of expanded strings. The expansion is computed as combinations of substrings separated by ',' and grouped recursively by '{}' (see the README of this library for more details). The result is ordered such that all expanded strings starting with a given substring in some group are generated before the next substring in the same group starts expanding. Examples:
fi{nd,ne,sh} -> [find, fine, fish]
r{u,a}{,i}n -> [run, ruin, ran, rain]
s{{a,o}{il,lv},l{ee,o}p}ing -> [sailing, salving, soiling, solving, sleeping, sloping]
An unmatched brace or a separator outside any brace pair is considered a syntax error. The function returns an appropriate Error immediately after such an error is encountered.
Types ¶
Click to show internal directories.
Click to hide internal directories.